@@ -4,7 +4,7 @@ use warnings;
 use base qw{Pod::Parser};
 
 # Set our version
-our $VERSION = '0.00001';
+our $VERSION = '0.00002';
 
 # Hold data for our pending statement
 my $info = {};
@@ -311,6 +311,8 @@ Some options will passing to Text::Template->new() for each parsed statement. By
 
     DELIMITERS => ['{%', '%}'],
 
+=back
+
 =head2 instance(file, <options>)
 
 Return singleton dictionary object, parsed $file keys will collapse/override with previous files. Same options as C<new>, I<tt> option merge with previous options of instance invokes.
@@ -319,9 +321,7 @@ Return singleton dictionary object, parsed $file keys will collapse/override wit
 
 Fill in dictionary sql with variables by L<Text::Template#HASH>. Other syntax:
 
-    $sql->{$key}->template(var1 => ..., var2 => ...)
-
-=back
+    $pos->{$key}->template(var1 => ..., var2 => ...)
 
 =head1 SEE ALSO
 
